'use strict';
import { SfCommand, Flags } from '@salesforce/sf-plugins-core';
import { Messages } from '@salesforce/core';
import { extractTestClasses } from '../../service/extractTestClasses.js';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('apex-tests-git-delta', 'delta');
export default class ApexTestDelta extends SfCommand {
    static summary = messages.getMessage('summary');
    static description = messages.getMessage('description');
    static examples = messages.getMessages('examples');
    static flags = {
        to: Flags.string({
            char: 't',
            summary: messages.getMessage('flags.to.summary'),
            required: true,
            default: 'HEAD',
        }),
        from: Flags.string({
            char: 'f',
            summary: messages.getMessage('flags.from.summary'),
            required: true,
        }),
        'skip-test-validation': Flags.boolean({
            char: 'v',
            summary: messages.getMessage('flags.skip-test-validation.summary'),
            required: true,
            default: false,
        }),
    };
    async run() {
        const { flags } = await this.parse(ApexTestDelta);
        const toGitRef = flags['to'];
        const fromGitRef = flags['from'];
        const validate = flags['skip-test-validation'];
        const result = await extractTestClasses(fromGitRef, toGitRef, validate);
        const tests = result.validatedClasses;
        const warnings = result.warnings;
        if (warnings.length > 0) {
            warnings.forEach((warning) => {
                this.warn(warning);
            });
        }
        this.log(tests);
        return { tests, warnings };
    }
}
//# sourceMappingURL=delta.js.map