'use strict';
import { retrieveCommitMessages } from './retrieveCommitMessages.js';
import { validateClassPaths } from './validateClassPaths.js';
import { gitAdapter } from './gitAdapter.js';
export async function extractTestClasses(fromRef, toRef, skipValidate) {
    const testClasses = new Set();
    const git = gitAdapter();
    const { repoRoot, matchedMessages } = await retrieveCommitMessages(fromRef, toRef, git);
    matchedMessages.forEach((message) => {
        // Split the commit message by commas or spaces
        const classes = message.split(/,|\s/);
        classes.forEach((testClass) => {
            // Remove leading/trailing whitespaces and add non-empty strings to the set
            const trimmedClass = testClass.trim();
            if (trimmedClass !== '') {
                testClasses.add(trimmedClass);
            }
        });
    });
    let sortedClasses = Array.from(testClasses).sort((a, b) => a.localeCompare(b));
    if (skipValidate) {
        return { validatedClasses: sortedClasses.join(' '), warnings: [] };
    }
    const result = sortedClasses.length > 0
        ? await validateClassPaths(sortedClasses, toRef, repoRoot, git)
        : { validatedClasses: new Set(), warnings: [] };
    let validatedClasses = '';
    if (result.validatedClasses.size > 0) {
        sortedClasses = Array.from(result.validatedClasses);
        sortedClasses = sortedClasses.sort((a, b) => a.localeCompare(b));
        validatedClasses = sortedClasses.join(' ');
    }
    return { validatedClasses, warnings: result.warnings };
}
//# sourceMappingURL=extractTestClasses.js.map