'use strict';
import { getPackageDirectories } from './getPackageDirectories.js';
export async function validateClassPaths(unvalidatedClasses, toCommitHash, repoRoot, git) {
    const packageDirectories = await getPackageDirectories(repoRoot);
    const warnings = [];
    const validatedClasses = new Set();
    for (const unvalidatedClass of unvalidatedClasses) {
        let validated = false;
        for (const packageDirectory of packageDirectories) {
            const fileExists = await fileExistsInCommit(`${unvalidatedClass}.cls`, toCommitHash, packageDirectory, git);
            if (fileExists) {
                validatedClasses.add(unvalidatedClass);
                validated = true;
                break;
            }
        }
        if (!validated)
            warnings.push(`The class ${unvalidatedClass} was not found in any package directory found in commit ${toCommitHash} and will not be added to the delta test classes.`);
    }
    return { validatedClasses, warnings };
}
async function fileExistsInCommit(filePath, commitHash, directory, git) {
    try {
        const files = (await git.raw('ls-tree', '--name-only', '-r', commitHash, directory)).trim().split('\n');
        return files.some((file) => file.endsWith(filePath));
    }
    catch (error) {
        return false;
    }
}
//# sourceMappingURL=validateClassPaths.js.map